==> cloudfoundry-client-2.1.0.RELEASE-sources.jar: org/cloudfoundry/client/v2/organizations/_ListOrganizationServicesRequest.java <==
/*
 * Copyright 2013-2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.organizations;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.InFilterParameter;
import org.cloudfoundry.client.v2.IsFilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Services for the Organization operation
 */
@Value.Immutable
abstract class _ListOrganizationServicesRequest extends PaginatedRequest {

    /**
     * The active flag
     */
    @IsFilterParameter("active")
    @Nullable
    abstract Boolean getActive();

    /**
     * The labels
     */
    @InFilterParameter("label")
    @Nullable
    abstract List<String> getLabels();

    /**
     * The organization id
     */
    @JsonIgnore
    abstract String getOrganizationId();

    /**
     * The providers
     */
    @InFilterParameter("provider")
    @Nullable
    abstract List<String> getProviders();

    /**
     * The service broker ids
     */
    @InFilterParameter("service_broker_guid")
    @Nullable
    abstract List<String> getServiceBrokerIds();

}

==> cloudfoundry-client-3.3.0.RELEASE-sources.jar: org/cloudfoundry/client/v2/organizations/_ListOrganizationServicesRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.organizations;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.FilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Services for the Organization operation
 */
@Value.Immutable
abstract class _ListOrganizationServicesRequest extends PaginatedRequest {

    /**
     * The active flag
     */
    @FilterParameter("active")
    @Nullable
    abstract Boolean getActive();

    /**
     * The labels
     */
    @FilterParameter("label")
    @Nullable
    abstract List<String> getLabels();

    /**
     * The organization id
     */
    @JsonIgnore
    abstract String getOrganizationId();

    /**
     * The providers
     */
    @Deprecated
    @FilterParameter("provider")
    @Nullable
    abstract List<String> getProviders();

    /**
     * The service broker ids
     */
    @FilterParameter("service_broker_guid")
    @Nullable
    abstract List<String> getServiceBrokerIds();

}
